#
# spec file for package python-shortuuid
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-shortuuid
Version:        1.0.13
Release:        2.3
Summary:        A generator library for concise, unambiguous and URL-safe UUIDs
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/stochastic-technologies/shortuuid/
Source:         https://files.pythonhosted.org/packages/source/s/shortuuid/shortuuid-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
Requires:       python-base
BuildArch:      noarch
%python_subpackages

%description
A library that generates short, pretty, unambiguous unique IDs
by using an extensive, case-sensitive alphabet and omitting
similar-looking letters and numbers.

%prep
%setup -q -n shortuuid-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/shortuuid
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative shortuuid

%postun
%python_uninstall_alternative shortuuid

%files %{python_files}
%doc README.md
%license COPYING
%python_alternative %{_bindir}/shortuuid
%{python_sitelib}/shortuuid
%{python_sitelib}/shortuuid-%{version}.dist-info

%changelog
* Fri Jan 10 2025 Steve Kowalik <steven.kowalik@suse.com>
- We don't need to clean up the license from sitelib.
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 1.0.13:
  * require python 3.6+
  * switch to poetry
* Sun Jun 25 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.11:
  * Add Type hinting
  * add py.typed (PEP 561)
* Fri Oct  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v1.0.9
  No Upstream changelog
* Sun Jan  9 2022 John Vandenberg <jayvdb@gmail.com>
- Remove tests from runtime package
- Update to v1.0.8
  * Include the COPYING file in releases
- from v1.0.7
  * Add prefix and max_length to the Django field
- from v1.0.6
  * Fix compatibility for python versions older than 3.8
- from v1.0.5
  * Don't try to get the version from the pyproject.toml
  * Fix slow loading times from using pkg_resources
- from v1.0.4
  * Fix the cli interface that the previous release broke
- from v1.0.3
  * Add Django ShortUUIDField
- from v1.0.2
  * Added basic input type validation to encode and decode
  * Use sys.version_info since sys.version returns string that
    interprets 3.10 as 3.1 in comparison
* Wed Mar 18 2020 pgajdos@suse.com
- version update to 1.0.1
  * Use README as the long description on PyPI. [Stavros Korokithakis]
  * Drop support for Python before 3.5. [Stavros Korokithakis]
  * Add simple command-line interface (#43) [Éric Araujo]
  * Make encode and decode MSB-first (#36) [Keane Nguyen]
  * Make the URL check more robust (fixes #32) [Stavros Korokithakis]
- deleted patches
  - shortuuid-no-pep8.patch (upstreamed)
* Wed Sep 26 2018 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to not depend on pep8 linter, also reported upstream
  to fix properly:
  * shortuuid-no-pep8.patch
* Sat Apr 28 2018 toddrme2178@gmail.com
- Initial version
